<?php
/**
 * Exit if accessed directly
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if( !class_exists( 'MWB_WRP_Admin_Class' ) )
{
	/**
	 * This is class for managing order status and other functionalities .
	 *
	 * @name    MWB_WRP_Product_Class
	 * @category Class
	 * @author   makewebbetter <webmaster@makewebbetter.com>
	 */

	class MWB_WRP_Admin_Class{
		/**
		 * This is construct of class where all action and filter is defined
		 *
		 * @name __construct
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 */
		
		public function __construct( )
		{
			add_action( 'admin_menu', array($this, 'mwb_wrp_admin_menu') );
			add_action('admin_enqueue_scripts',array($this,'mwb_wrp_load_admin_script'));
			add_action('wp_ajax_mwb_wrp_register_license',array($this,'mwb_wrp_check_license'));
		}


		/**
		 * This function is used to verify the license
		 *
		 * @name mwb_wrp_check_license
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 */
		function mwb_wrp_check_license()
		{
			check_ajax_referer( 'mwb-wrp-verify-nonce', 'mwb_nonce' );
			$mwb_license_key = sanitize_text_field( $_POST['license_key'] );
			$mwb_admin_name = '';
			$mwb_admin_email = get_option( 'admin_email', null );
			$mwb_admin_details = get_user_by('email', $admin_email);
			if(isset($mwb_admin_details->data))
			{
				if(isset($mwb_admin_details->data->display_name))
				{
					$mwb_admin_name = $mwb_admin_details->data->display_name;
				}
			}
			$mwb_license_arr = array(
				'license_key' => $mwb_license_key,
				'domain_name' => $_SERVER['HTTP_HOST'],
				'admin_name' => $mwb_admin_name,
				'admin_email' => $mwb_admin_email,
				'plugin_name' => 'woo recommended products'
			);
			$curl = curl_init();

			curl_setopt_array($curl, array(
			  CURLOPT_URL => "https://makewebbetter.com/codecanyon/validate_license.php",
			  CURLOPT_RETURNTRANSFER => true,
			  CURLOPT_ENCODING => "",
			  CURLOPT_MAXREDIRS => 10,
			  CURLOPT_SSL_VERIFYHOST => false,
			  CURLOPT_SSL_VERIFYPEER => false,
			  CURLOPT_TIMEOUT => 30,
			  CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
			  CURLOPT_CUSTOMREQUEST => "POST",
			  CURLOPT_POSTFIELDS => http_build_query($mwb_license_arr),
			  CURLOPT_HTTPHEADER => array(
			    "cache-control: no-cache",
			    "content-type: application/x-www-form-urlencoded",
			    "postman-token: d9d9a28b-94cc-7a0e-47b2-5bd10aa7aa89"
			  ),
			));

			$mwb_res = curl_exec($curl);
			$err = curl_error($curl);

			curl_close($curl);

			if ($err) {
			  echo "cURL Error #:" . $err;
			 }
		 	$mwb_res = json_decode($mwb_res,true);
		 	if( $mwb_res['status'] == true )
		 	{
		 		update_option('mwb_wrp_license_hash',$mwb_res['hash']);
		 		update_option('mwb_wrp_plugin_name','woo recommended products');
		 		update_option('mwb_wrp_license_key',$mwb_res['mwb_key']);
		 		echo json_encode( array('status'=>true,'msg'=>__('Successfully Verified','woocommerce-recommended-product') ) );
		 	}
		 	else if( $mwb_res['status'] == false )
		 	{
		 		echo json_encode( array('status'=>false,'msg'=> $mwb_res['msg']) );
		 	}
			wp_die();
		}

		
		public function mwb_wrp_admin_menu()
		{
			$page_title = __("Woo Recommended Products", "woocommerce-recommended-product");
			$menu_title = __("Woo Recommended Products", "woocommerce-recommended-product");
			$capability = "manage_options";
			$menu_slug = "mwb_wrp_recommended_products";
			add_submenu_page('woocommerce', $page_title, $menu_title, $capability, $menu_slug, array($this, 'mwb_wrp_recommended_product_setting'));
		}


		public function mwb_wrp_load_admin_script()
		{
			wp_enqueue_script( 'mwb-wrp-admin-js-1', MWB_WRP_URL.'assets/js/mwb_wrp_admin.js', array( 'jquery' ), false, true );
            $mwb_local_arr = array(
            	'ajax_url'=>admin_url( 'admin-ajax.php' ),
            	'mwb_wrp_nonce'=>wp_create_nonce( "mwb-wrp-verify-nonce" )
            );
            wp_localize_script('mwb-wrp-admin-js-1','mwb_wrp_js_obj',$mwb_local_arr);
		}

		
		public function mwb_wrp_recommended_product_setting(){
			include_once MWB_WRP_DIRPATH.'/admin/woocommerce-recommended-product-admin-setting.php';
		}
	}
	new MWB_WRP_Admin_Class();
}
?>