<?php
/**
 * Exit if accessed directly
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if( !class_exists( 'MWB_WRP_Product_Class' ) )
{
	/**
	 * This is class for managing order status and other functionalities .
	 *
	 * @name    MWB_WRP_Product_Class
	 * @category Class
	 * @author   makewebbetter <webmaster@makewebbetter.com>
	 */

	class MWB_WRP_Product_Class{
		/**
		 * This is construct of class where all action and filter is defined
		 *
		 * @name __construct
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 */
		public function __construct( )
		{
			
			add_shortcode( 'mwb_wrp_products', array($this, 'mwb_wrp_products') );
			add_shortcode( 'mwb_wrp_category_products', array($this, 'mwb_wrp_category_products') );
			add_shortcode( 'mwb_wrp_onsale_products', array($this, 'mwb_wrp_onsale_products') );
			add_shortcode( 'mwb_wrp_products_sale', array($this, 'mwb_wrp_products_sale') );
			add_shortcode( 'mwb_wrp_products_trending', array($this, 'mwb_wrp_products_trending') );
			add_action( 'mwb_wrp_woocommerce_after_shop_loop_item', array($this, 'mwb_wrp_woocommerce_template_loop_product_link_close'), 5);
			add_action( 'mwb_wrp_woocommerce_after_shop_loop_item', array($this, 'mwb_wrp_woocommerce_template_loop_add_to_cart'), 10);
			add_action( 'mwb_wrp_woocommerce_before_shop_loop_item', array($this, 'mwb_wrp_woocommerce_template_loop_product_link_open'), 10);
			add_action( 'woocommerce_before_single_product_summary', array($this, 'mwb_wrp_woocommerce_before_single_product_summary'), 10 );
			add_action( 'init', array($this, 'mwb_wrp_init'), 10 );
			add_action( 'woocommerce_add_to_cart', array($this, 'mwb_wrp_woocommerce_add_to_cart'), 10, 6);
			add_action( 'woocommerce_remove_cart_item', array($this, 'mwb_wrp_woocommerce_remove_cart_item'),10, 2 );
			add_action( 'woocommerce_checkout_order_processed', array($this, 'mwb_wrp_woocommerce_checkout_order_processed'), 10, 3 );
			add_action( 'woocommerce_after_checkout_form', array($this, 'mwb_wrp_woocommerce_after_checkout_form') );
			add_action( 'admin_enqueue_scripts', array($this, 'mwb_wrp_admin_enqueue_scripts') );
			add_action( 'wp_ajax_mwb_wrp_set_price', array($this, 'mwb_wrp_set_price'));
			add_action( 'wp_ajax_nopriv_mwb_wrp_set_price', array($this, 'mwb_wrp_set_price'));
			
		}
		
		/**
		 * This is a function which is for setting the price
		 *
		 * @name mwb_wrp_set_price
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 */
		function mwb_wrp_set_price(){
			$response['success'] = false;
			$product_id = $_POST['productid'];
			$price = $_POST['price'];
			if($price > 0){
				$product = get_product( $product_id );
				if( $product->is_type( 'variable' ) ){
					$variation_ids = $product->get_children();
					
					foreach ($variation_ids as $variation_id){
						$variableproduct = new WC_Product_Variation($variation_id);
						$productprice = $variableproduct->get_price();
						if(isset($productprice) && !empty($productprice)){
							if($productprice > $price){
								$newprice = $productprice - $price;
								update_post_meta($variation_id, '_sale_price', $newprice);
								update_post_meta($variation_id, '_price', $newprice);
								$response['success'] = true;
							}
						}
						$variableproduct->save();
					}
				}
				if( $product->is_type( 'simple' ) ){
					$productprice = $product->get_price();
					if(isset($productprice) && !empty($productprice)){
						if($productprice > $price){
							$newprice = $productprice - $price;
							update_post_meta($product_id, '_sale_price', $newprice);
							update_post_meta($product_id, '_price', $newprice);
							$response['success'] = true;
						}
					}
				}
			}
			echo json_encode($response);
			die;
		}
		
		/**
		 * This is a function to enqueue scripts and style
		 *
		 * @name mwb_wrp_admin_enqueue_scripts
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 */
		function mwb_wrp_admin_enqueue_scripts(){
			wp_enqueue_style('mwb_wrp_admin_css', MWB_WRP_URL."/assets/css/mwb_wpr_admin.css");
			wp_enqueue_style('mwb_wrp_datatable_css', "https://cdn.datatables.net/1.10.15/css/jquery.dataTables.min.css");
			wp_enqueue_script('mwb_wrp_datatable_js', "https://cdn.datatables.net/1.10.15/js/jquery.dataTables.min.js", array('jquery'));
			
			$mwb_wrp = array(
					'ajaxurl' => admin_url('admin-ajax.php'),
			);
			
			wp_register_script('mwb_wrp_admin_js', MWB_WRP_URL."/assets/js/mwb_wpr_admin.js", array('jquery', 'mwb_wrp_datatable_js'));
			wp_localize_script('mwb_wrp_admin_js', 'mwb_wrp', $mwb_wrp );
			wp_enqueue_script('mwb_wrp_admin_js' );
		}
		
		/**
		 * This is a function to tracking checkout page
		 *
		 * @name mwb_wrp_woocommerce_after_checkout_form
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 */
		function mwb_wrp_woocommerce_after_checkout_form($checkout)
		{
			global $wpdb;
			$table_name = $wpdb->prefix . 'mwb_wpr_data';
			$action = "view_checkout";
			$ipaddress = $_SERVER['REMOTE_ADDR'];
			$userid = get_current_user_id();
			$productid = 0;
			$type = 'checkout';
			
			$this->mwb_wrp_insert_update($action, $productid, $type);
		}
		
		/**
		 * This is a function to tracking checkout success
		 *
		 * @name mwb_wrp_woocommerce_checkout_order_processed
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 */
		function mwb_wrp_woocommerce_checkout_order_processed($order_id, $posted_data, $order)
		{
			global $wpdb;
			$table_name = $wpdb->prefix . 'mwb_wpr_data';
			foreach ( $order->get_items() as $item_id => $item ) {
				$product = apply_filters( 'woocommerce_order_item_product', $item->get_product(), $item );
				$productid = $product->get_id();
				$data = array('status' => 1);
				$where = array('productid' => $productid);
				$wpdb->update( $table_name, $data, $where);
			}
		}
		
		/**
		 * This is a function to tracking remove cart item
		 *
		 * @name mwb_wrp_woocommerce_remove_cart_item
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 */
		function mwb_wrp_woocommerce_remove_cart_item($cart_item_key, $cart )
		{
			global $wpdb;
			$table_name = $wpdb->prefix . 'mwb_wpr_data';
			$cart_contents = $cart->cart_contents;
			$cart_item = $cart_contents[$cart_item_key];
			$productid = apply_filters( 'woocommerce_cart_item_product_id', $cart_item['product_id'], $cart_item, $cart_item_key );
			$action = "remove_cart";
			$ipaddress = $_SERVER['REMOTE_ADDR'];
			$userid = get_current_user_id();
			$type = 'cart';
			
			$this->mwb_wrp_insert_update($action, $productid, $type);
		}
		
		/**
		 * This is a function to remove old data
		 *
		 * @name mwb_wrp_woocommerce_remove_cart_item
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 */
		function mwb_wrp_init(){
			global $wpdb;
			$table_name = $wpdb->prefix . 'mwb_wpr_data';
			$noofdays = get_option('mwb_wrp_delete_data', false);
			$daystring = "-$noofdays days";
			$date = date('Y-m-d 00:00:00', strtotime($daystring, time()));
			$delete_query = "DELETE FROM `$table_name` WHERE `date` < '$date'";
			$wpdb->query($delete_query);
		}
		
		/**
		 * This is a function to track add to cart
		 *
		 * @name mwb_wrp_woocommerce_add_to_cart
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 */
		function mwb_wrp_woocommerce_add_to_cart($cart_item_key, $product_id, $quantity, $variation_id, $variation, $cart_item_data){
			global $wpdb;
			$table_name = $wpdb->prefix . 'mwb_wpr_data';
			$action = "add_to_cart";
			$ipaddress = $_SERVER['REMOTE_ADDR'];
			$userid = get_current_user_id();
			$productid = $product_id;
			if(isset($_GET['mwb_recommended'])){
				$type = "recommended";
			}else{
				$type = "normal";
			}
			$this->mwb_wrp_insert_update($action, $productid, $type);
		}
		
		/**
		 * This is a function to track product view
		 *
		 * @name mwb_wrp_woocommerce_before_single_product_summary
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 */
		function mwb_wrp_woocommerce_before_single_product_summary(){
			
			if(!isset($_POST['add-to-cart']))
			{	
				global $product, $wpdb;
				$table_name = $wpdb->prefix . 'mwb_wpr_data';
				$action = "view";
				$ipaddress = $_SERVER['REMOTE_ADDR'];
				$userid = get_current_user_id();
				$productid = $product->get_id();
				if(isset($_GET['mwb_recommended']))
				{
					$type = "recommended";
				}
				else
				{
					$type = "normal";
				}
				
				$this->mwb_wrp_insert_update($action, $productid, $type);
			}	
		}
		
		/**
		 * This is a function to insert/update data
		 *
		 * @name mwb_wrp_insert_update
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 */
		function mwb_wrp_insert_update($action, $productid, $type){
			
			global $wpdb;
			
			$table_name = $wpdb->prefix . 'mwb_wpr_data';
			$ipaddress = $_SERVER['REMOTE_ADDR'];
			$userid = get_current_user_id();
			
			$data['action'] = $action;
			$data['userid'] = $userid;
			$data['ipaddress'] = $ipaddress;
			$data['productid'] = $productid;
			$data['type'] = $type;
			$data['count'] = 1;
			
			$query = "SELECT `id`, `count` FROM `$table_name` WHERE `action` LIKE '$action' AND `userid` = $userid AND `ipaddress` LIKE '$ipaddress' AND `productid` = $productid AND `type` LIKE '$type' AND `status` = 0";
			$ids = $wpdb->get_results($query, ARRAY_A);
			
			if(isset($ids) && !empty($ids)){
				$id = $ids[0]['id'];
				$count = $ids[0]['count'];
				$count = $count + 1;
				$data = array('count' => $count);
				$where = array('id' => $id);
				$wpdb->update( $table_name, $data, $where);
			}else{
				$wpdb->insert( $table_name, $data);
			}
		}
		
		/**
		 * Insert the opening anchor tag for products in the loop.
		 *
		 * @name mwb_wrp_woocommerce_template_loop_product_link_open
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 */
		function mwb_wrp_woocommerce_template_loop_product_link_open() {
			global $product;
			$productid = $product->get_id();
			
			$producturl = get_the_permalink();
			$producturl = add_query_arg( array(
					'mwb_recommended' => $productid,
			), $producturl );
			
			
			echo '<a href="' . $producturl . '" class="woocommerce-LoopProduct-link">';
		}
		
		/**
		 * Insert the closing anchor tag for products in the loop.
		 *
		 * @name mwb_wrp_woocommerce_template_loop_product_link_close
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 */
		function mwb_wrp_woocommerce_template_loop_product_link_close(){
			echo "</a>";
		}
		
		/**
		 * Loop the product
		 *
		 * @name mwb_wrp_woocommerce_template_loop_add_to_cart
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 */
		function mwb_wrp_woocommerce_template_loop_add_to_cart( $args = array() ) {
			global $product;
			if ( $product ) {
				$defaults = array(
					'quantity' => 1,
					'class'    => implode( ' ', array_filter( array(
							'button',
							'product_type_' . $product->get_type(),
							$product->is_purchasable() && $product->is_in_stock() ? 'add_to_cart_button' : '',
							$product->supports( 'ajax_add_to_cart' ) ? 'ajax_add_to_cart' : '',
					) ) ),
				);
	
				$args = apply_filters( 'woocommerce_loop_add_to_cart_args', wp_parse_args( $args, $defaults ), $product );
	
				$class = $args['class'];
				$quantity = $args['quantity'];
				
				$template_name = 'loop/add-to-cart.php';
				$template_path = ''; 
				$located = '';
				
				do_action( 'woocommerce_before_template_part', $template_name, $template_path, $located, $args );
				
				$producturl = $product->add_to_cart_url();
				$productid = $product->get_id();
				
				$producturl = add_query_arg( array(
				'mwb_recommended' => $productid,
				), $producturl );
				
				echo apply_filters( 'woocommerce_loop_add_to_cart_link',
						sprintf( '<a rel="nofollow" href="%s" data-quantity="%s" data-product_id="%s" data-product_sku="%s" class="%s">%s</a>',
								esc_url( $producturl ),
								esc_attr( isset( $quantity ) ? $quantity : 1 ),
								esc_attr( $product->get_id() ),
								esc_attr( $product->get_sku() ),
								esc_attr( isset( $class ) ? $class : 'button' ),
								esc_html( $product->add_to_cart_text() )
						),
						$product );
				
				do_action( 'woocommerce_after_template_part', $template_name, $template_path, $located, $args );
			}
		}



		/**
		 * This is shortcode for listing the recommended products categorywise
		 *
		 * @name mwb_wrp_category_products
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 */
		public function mwb_wrp_category_products($atts)
		{
			global $wpdb;
			$count = 4;
			if(isset($atts['count']))
			{
				if($atts['count'] != 0){
					$count = $atts['count'];
				}
			}
			$columns = 4;
			if(isset($atts['columns']))
			{
				if($atts['columns'] != 0){
					$columns = $atts['columns'];
				}
			}
			
			// Fetch products from table
			
			$productcats = array();
			$product_ids = array();
			$user_id = get_current_user_id();
			$table_name = $wpdb->prefix . 'mwb_wpr_data';
			$ipaddress = $_SERVER['REMOTE_ADDR'];
			
			if($user_id > 0)
			{
				$query = "SELECT `productid` FROM `$table_name`	WHERE `userid` = '$user_id' ORDER BY `count` DESC, `date` DESC";
			}
			else
			{
				$query = "SELECT `productid` FROM `$table_name`	WHERE `ipaddress` = '$ipaddress' ORDER BY `count` DESC, `date` DESC";
			}
			
			$trackproducts = $wpdb->get_results($query, ARRAY_A);
			if(isset($trackproducts) && !empty($trackproducts))
			{
				foreach ($trackproducts as $trackproduct)
				{
					$product_id = $trackproduct['productid'];
					$terms = get_the_terms( $product_id, 'product_cat' );
					if(isset($terms) && !empty($terms))
					{
						// Fetch products from product category
						
						foreach($terms as $term)
						{
							$productterm = $term->term_id;
							$args = array(
									'post_type' => 'product',
									'meta_key' => 'total_sales',
									'orderby' => 'meta_value',
									'order' => 'DESC',
									'tax_query' => array(
											array(
													'taxonomy' => 'product_cat',
													'field'    => 'term_id',
													'terms'    => $productterm,
											),
									),
							);
							$query = new WP_Query( $args );
							if ( $query->have_posts() ) 
							{
								while ( $query->have_posts() )
								{
									$query->the_post();
									$product_id = get_the_ID();
									$product_ids[] = $product_id;
								}
								wp_reset_query();
							}
						}
					}
				}
				$product_ids = array_unique($product_ids);
				$pagelink = get_permalink();
			
				if(empty($_SERVER['HTTP_REFERER']) || ($_SERVER['HTTP_REFERER'] == $pagelink))
				{
					shuffle($product_ids);
				}
				if ( !empty( $product_ids ) ) 
				{
					$product_ids = array_slice($product_ids, 0,$count);
					$shrt = '[products ids="'.implode(',', $product_ids).'" columns="'.$columns.'"]';
					return do_shortcode($shrt);
				}
				elseif ( ! woocommerce_product_subcategories( array( 'before' => woocommerce_product_loop_start( false ), 'after' => woocommerce_product_loop_end( false ) ) ) ) 
				{
					do_action( 'woocommerce_no_products_found' );
				}
			}
		}


		/**
		 * This is shortcode for listing the recommended products which is onsale
		 *
		 * @name mwb_wrp_onsale_products
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 */
		public function mwb_wrp_onsale_products($atts)
		{
			global $wpdb;
			$count = 4;
			if(isset($atts['count']))
			{
				if($atts['count'] != 0){
					$count = $atts['count'];
				}
			}
			$columns = 4;
			if(isset($atts['columns']))
			{
				if($atts['columns'] != 0){
					$columns = $atts['columns'];
				}
			}
			
			$productcats = array();
			$product_ids = array();
			$user_id = get_current_user_id();
			$table_name = $wpdb->prefix . 'mwb_wpr_data';
			$ipaddress = $_SERVER['REMOTE_ADDR'];
			
			if($user_id > 0)
			{
				$query = "SELECT `productid` FROM `$table_name`	WHERE `userid` = '$user_id' ORDER BY `count` DESC, `date` DESC";
			}
			else
			{
				$query = "SELECT `productid` FROM `$table_name`	WHERE `ipaddress` = '$ipaddress' ORDER BY `count` DESC, `date` DESC";
			}
			
			$trackproducts = $wpdb->get_results($query, ARRAY_A);
			if(isset($trackproducts) && !empty($trackproducts))
			{
				foreach ($trackproducts as $trackproduct)
				{
					$product_id = $trackproduct['productid'];
					$terms = get_the_terms( $product_id, 'product_cat' );
					if(isset($terms) && !empty($terms))
					{
						// Fetch products from product category
						
						foreach($terms as $term)
						{
							$productterm = $term->term_id;
							$args = array(
									'post_type' => 'product',
									'orderby' => 'meta_value',
									'order' => 'DESC',
									'posts_per_page' => -1,
									'meta_query'     => array(
											'relation' => 'OR',
											array( // Simple products type
													'key'           => '_sale_price',
													'value'         => 0,
													'compare'       => '>',
													'type'          => 'numeric'
											),
											array( // Variable products type
													'key'           => '_min_variation_sale_price',
													'value'         => 0,
													'compare'       => '>',
													'type'          => 'numeric'
											)
									),
									'tax_query' => array(
											array(
													'taxonomy' => 'product_cat',
													'field'    => 'term_id',
													'terms'    => $productterm,
											),
									)
							);
							$query = new WP_Query( $args );
							if ( $query->have_posts() ) 
							{
								while ( $query->have_posts() )
								{
									$query->the_post();
									$product_id = get_the_ID();
									$mwb_obj = wc_get_product($product_id);
									if( $mwb_obj->is_on_sale() )
									{
										$product_ids[] = $product_id;
									}
								}
								wp_reset_query();
							}
						}
					}
				}
			}
			$product_ids = array_unique($product_ids);
			$pagelink = get_permalink();
		
			if(empty($_SERVER['HTTP_REFERER']) || ($_SERVER['HTTP_REFERER'] == $pagelink))
			{
				shuffle($product_ids);
			}
			if ( !empty( $product_ids ) ) 
			{
				$product_ids = array_slice($product_ids, 0,$count);
				$shrt = '[products ids="'.implode(',', $product_ids).'" columns="'.$columns.'"]';
				return do_shortcode($shrt);
			}
			elseif ( ! woocommerce_product_subcategories( array( 'before' => woocommerce_product_loop_start( false ), 'after' => woocommerce_product_loop_end( false ) ) ) ) 
			{
				do_action( 'woocommerce_no_products_found' );
			}
			
		}



		/**
		 * This is shortcode for listing the recommended products which is in trending
		 *
		 * @name mwb_wrp_category_products
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 */
		public function mwb_wrp_products_trending($atts)
		{
			global $wpdb;
			$count = 4;
			if(isset($atts['count']))
			{
				if($atts['count'] != 0){
					$count = $atts['count'];
				}
			}
			$columns = 4;
			if(isset($atts['columns']))
			{
				if($atts['columns'] != 0){
					$columns = $atts['columns'];
				}
			}
			
			$productcats = array();
			$product_ids = array();
			$categories = get_option('mwb_wrp_product_categories', false);
			$args = array(
					'post_type' => 'product',
					'meta_key' => 'total_sales',
					'orderby' => 'meta_value',
					'order' => 'DESC',
					'tax_query' => array(
							array(
									'taxonomy' => 'product_cat',
									'field'    => 'term_id',
									'terms'    => $categories,
							),
					),
			);
			
			$query = new WP_Query( $args );
			
			if ( $query->have_posts() ) {
				while ( $query->have_posts() )
				{
					$query->the_post();
					$product_id = get_the_ID();
					$product_ids[] = $product_id;
				}
				wp_reset_query();
			}
			$product_ids = array_unique($product_ids);
			$pagelink = get_permalink();
		
			if(empty($_SERVER['HTTP_REFERER']) || ($_SERVER['HTTP_REFERER'] == $pagelink))
			{
				shuffle($product_ids);
			}
			if ( !empty( $product_ids ) ) 
			{
				$product_ids = array_slice($product_ids, 0,$count);
				$shrt = '[products ids="'.implode(',', $product_ids).'" columns="'.$columns.'"]';
				return do_shortcode($shrt);
			}
			elseif ( ! woocommerce_product_subcategories( array( 'before' => woocommerce_product_loop_start( false ), 'after' => woocommerce_product_loop_end( false ) ) ) ) 
			{
				do_action( 'woocommerce_no_products_found' );
			}
			
		}

		

		/**
		 * This is shortcode for listing the recommended products
		 *
		 * @name mwb_wrp_products
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 */
		public function mwb_wrp_products($atts)
		{
			global $wpdb;
			$count = 4;
			if(isset($atts['count']))
			{
				if($atts['count'] != 0){
					$count = $atts['count'];
				}
			}
			$columns = 4;
			if(isset($atts['columns']))
			{
				if($atts['columns'] != 0){
					$columns = $atts['columns'];
				}
			}
			$orderby = 4;
			if(isset($atts['columns']))
			{
				if($atts['columns'] != 0){
					$columns = $atts['columns'];
				}
			}
			
			// Fetch products from table
			
			$productcats = array();
			$product_ids = array();
			$user_id = get_current_user_id();
			$table_name = $wpdb->prefix . 'mwb_wpr_data';
			$ipaddress = $_SERVER['REMOTE_ADDR'];
			
			if($user_id > 0)
			{
				$query = "SELECT `productid` FROM `$table_name`	WHERE `userid` = '$user_id' ORDER BY `count` DESC, `date` DESC";
			}
			else
			{
				$query = "SELECT `productid` FROM `$table_name`	WHERE `ipaddress` = '$ipaddress' ORDER BY `count` DESC, `date` DESC";
			}
			
			$trackproducts = $wpdb->get_results($query, ARRAY_A);
			if(isset($trackproducts) && !empty($trackproducts))
			{
				foreach ($trackproducts as $trackproduct)
				{
					$product_id = $trackproduct['productid'];
					$product_ids[] = $product_id;
					$terms = get_the_terms( $product_id, 'product_cat' );
					if(isset($terms) && !empty($terms))
					{
						// Fetch products from product category
						
						foreach($terms as $term)
						{
							$productterm = $term->term_id;
							$args = array(
									'post_type' => 'product',
									'meta_key' => 'total_sales',
									'orderby' => 'meta_value',
									'order' => 'DESC',
									'tax_query' => array(
											array(
													'taxonomy' => 'product_cat',
													'field'    => 'term_id',
													'terms'    => $productterm,
											),
									),
							);
							$query = new WP_Query( $args );
							if ( $query->have_posts() ) 
							{
								while ( $query->have_posts() )
								{
									$query->the_post();
									$product_id = get_the_ID();
									$product_ids[] = $product_id;
								}
								wp_reset_query();
							}
						}
					}
				}
				$product_ids = array_unique($product_ids);
			}
			
			//Sale Products
				
			$args = array(
					'post_type'      => 'product',
					'posts_per_page' => -1,
					'meta_query'     => array(
							'relation' => 'OR',
							array( // Simple products type
									'key'           => '_sale_price',
									'value'         => 0,
									'compare'       => '>',
									'type'          => 'numeric'
							),
							array( // Variable products type
									'key'           => '_min_variation_sale_price',
									'value'         => 0,
									'compare'       => '>',
									'type'          => 'numeric'
							)
					)
			);
				
			$query = new WP_Query( $args );
				
			if ( $query->have_posts() ) {
				while ( $query->have_posts() )
				{
					$query->the_post();
					$product_id = get_the_ID();
					$mwb_obj = wc_get_product($product_id);
					if( $mwb_obj->is_on_sale() )
					{
						$product_ids[] = $product_id;
					}
				}
					
				wp_reset_query();
			}
			
			// Fetch products from product sale
			
			$args = array(
					'post_type' => 'product',
					'meta_key' => 'total_sales',
					'orderby' => 'meta_value',
					'order' => 'DESC',
					'posts_per_page' => -1,
			);
			
			$query = new WP_Query( $args );
				
			if ( $query->have_posts() ) {
				while ( $query->have_posts() )
				{
					$query->the_post();
					$product_id = get_the_ID();
					$product_ids[] = $product_id;
				}
				
				wp_reset_query();
			}
			
			// Fetch products from trending categories
			
			$categories = get_option('mwb_wrp_product_categories', false);
			$args = array(
					'post_type' => 'product',
					'meta_key' => 'total_sales',
					'orderby' => 'meta_value',
					'order' => 'DESC',
					'tax_query' => array(
							array(
									'taxonomy' => 'product_cat',
									'field'    => 'term_id',
									'terms'    => $categories,
							),
					),
			);
			
			$query = new WP_Query( $args );
			
			if ( $query->have_posts() ) {
				while ( $query->have_posts() )
				{
					$query->the_post();
					$product_id = get_the_ID();
					$product_ids[] = $product_id;
				}
				wp_reset_query();
			}
			
			$product_ids = array_unique($product_ids);
			
			$pagelink = get_permalink();
			
			if(empty($_SERVER['HTTP_REFERER']) || ($_SERVER['HTTP_REFERER'] == $pagelink))
			{
				shuffle($product_ids);
			}
			
			if ( !empty( $product_ids ) ) 
			{
				$product_ids = array_slice($product_ids, 0,$count);
				$shrt = '[products ids="'.implode(',', $product_ids).'" columns="'.$columns.'"]';
				return do_shortcode($shrt);
			}
			elseif ( ! woocommerce_product_subcategories( array( 'before' => woocommerce_product_loop_start( false ), 'after' => woocommerce_product_loop_end( false ) ) ) ) 
			{
				do_action( 'woocommerce_no_products_found' );
			}
		}
	}
	
	new MWB_WRP_Product_Class();
}
?>