<?php
/**
 * Return the default suggested privacy policy content.
 * @return string The default policy content.
 */
function mwb_wrp_plugin_get_default_privacy_content() {
  return  '<h2>' . __( 'Store User Ip Address for Product Recommendation','woocommerce-recommended-product' ) . '</h2>' .
  '<p>' . __( 'We store ip address of customer for making best recommendation for user next visit.','woocommerce-recommended-product' ) . '</p>';
}

/**
 * Add the suggested privacy policy text to the policy postbox.
 */
function mwb_wrp_plugin_add_suggested_privacy_content() {
  $content = mwb_wrp_plugin_get_default_privacy_content();
  wp_add_privacy_policy_content( __( 'WooCommerce Recommended Product','woocommerce-recommended-product' ), $content );
}

add_action( 'admin_init', 'mwb_wrp_plugin_add_suggested_privacy_content', 20 );


//////////////////////////////////////////////////////////////////
////////////////////////Export Personal Data//////////////////////
//////////////////////////////////////////////////////////////////


/**
 * Register exporter for Plugin user data.
 * @see https://github.com/allendav/wp-privacy-requests/blob/master/EXPORT.md
 * @param $exporters
 * @return array
 */
function mwb_wrp_plugin_register_exporters( $exporters ) {
  $exporters[] = array(
    'exporter_friendly_name' => __( 'User Ip address', 'woocommerce-recommended-product' ),
    'callback'               => 'mwb_wrp_plugin_user_data_exporter',
  );
  return $exporters;
}

add_filter( 'wp_privacy_personal_data_exporters', 'mwb_wrp_plugin_register_exporters' );

/**
 * Exporter for Plugin user data.
 * @see https://github.com/allendav/wp-privacy-requests/blob/master/EXPORT.md
 * @param     $email_address
 * @param int $page
 * @return array
 */
function mwb_wrp_plugin_user_data_exporter( $email_address, $page = 1 ) {
  $export_items = array();
  $user = get_user_by( 'email', $email_address );
  if ( $user && $user->ID ) {

    $item_id = "mwb-wrp-user-ip-{$user->ID}";
    
    $group_id = 'mwb-wrp-user-ip';
   
    $group_label = __( 'User Ip Address', 'woocommerce-recommended-product' );

    // Plugins can add as many items in the item data array as they want
    $data = array();
    
    // Add the users ip address
    global $wpdb;
	$table_name = $wpdb->prefix . 'mwb_wpr_data';

	$fetchquery = "SELECT DISTINCT(`ipaddress`) FROM `$table_name` WHERE `userid`= '$user->ID'";
	$ipaddress = $wpdb->get_results($fetchquery);
	if(is_array($ipaddress) && !empty($ipaddress))
	{
		$mwb_wrp_user_id = '';
		foreach ($ipaddress as $value) {
			if($mwb_wrp_user_id == '')
			{

				$mwb_wrp_user_id = $value->ipaddress;
			}
			else
			{
				$mwb_wrp_user_id .= ' , '.$value->ipaddress;
			}
		}
	    if ( $mwb_wrp_user_id ) {
	      $data[] = array(
	        'name'  => __( 'Ip Address', 'woocommerce-recommended-product' ),
	        'value' => $mwb_wrp_user_id,
	      );
	    }

	    // Add this group of items to the exporters data array.
	    $export_items[] = array(
	      'group_id'    => $group_id,
	      'group_label' => $group_label,
	      'item_id'     => $item_id,
	      'data'        => $data,
	    );
	}
  }
  // Returns an array of exported items for this pass, but also a boolean whether this exporter is finished.
  //If not it will be called again with $page increased by 1.
  return array(
    'data' => $export_items,
    'done' => true,
  );
}

////////////////////////////////////////////////////////////////
//////////////////////Delete Personal Data//////////////////////
////////////////////////////////////////////////////////////////

/**
 * Register eraser for Plugin user data.
 * @param array $erasers
 * @return array
 */
function mwb_wrp_plugin_register_erasers( $erasers = array() ) {
  $erasers[] = array(
    'eraser_friendly_name' => __( 'User Ip Address', 'woocommerce-recommended-product' ),
    'callback'               => 'mwb_wrp_plugin_user_data_eraser',
  );
  return $erasers;
}

add_filter( 'wp_privacy_personal_data_erasers', 'mwb_wrp_plugin_register_erasers' );

/**
 * Eraser for Plugin user data.
 * @param     $email_address
 * @param int $page
 * @return array
 */
function mwb_wrp_plugin_user_data_eraser( $email_address, $page = 1 ) {
  if ( empty( $email_address ) ) {
    return array(
      'items_removed'  => false,
      'items_retained' => false,
      'messages'       => array(),
      'done'           => true,
    );
  }
  $user         = get_user_by( 'email', $email_address );
  $messages = array();
  $items_removed  = false;
  $items_retained = false;
  if ( $user && $user->ID ) {
    // Delete their fb url
    global $wpdb;
	$table_name = $wpdb->prefix . 'mwb_wpr_data';

	$select_query = "SELECT * FROM `$table_name` WHERE `userid` = '$user->ID'";
	$select_result = $wpdb->query($select_query);

	if($select_result > 0)
	{
	   	$delete_query = "DELETE FROM `$table_name` WHERE `userid` = '$user->ID'";
	  	$status = $wpdb->query($delete_query);
	    if ( $status ) {
	      $items_removed = true;
	    } else {
	      $messages[] = __( 'Your Ip Address was unable to be removed at this time.', 'woocommerce-recommended-product');
	      $items_retained = true;
	    }
	}
	else
	{
		 $items_removed = true;
	}
   
  }
  // Returns an array of exported items for this pass, but also a boolean whether this exporter is finished.
  //If not it will be called again with $page increased by 1.
  return array(
    'items_removed'  => $items_removed,
    'items_retained' => $items_retained,
    'messages'       => $messages,
    'done'           => true,
  );
}