<?php
/**
 * Plugin Name:  WooCommerce Recommended Product
 * Plugin URI: http://makewebbetter.com
 * Description: This woocommerce extension use AI to list all products
 * Version: 1.0.3
 * Author: پرشین اسکریپت 
 * Author URI: http://www.persianscript.ir
 * Requires at least: 3.5
 * Tested up to: 4.4.2
 * Text Domain: woocommerce-recommended-product
 * Domain Path: /languages
 */

/**
 * Exit if accessed directly
 */


if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

$activated = true;
if (function_exists('is_multisite') && is_multisite())
{
	include_once( ABSPATH . 'wp-admin/includes/plugin.php' );
	if ( !is_plugin_active( 'woocommerce/woocommerce.php' ) )
	{
		$activated = false;
	}
}
else
{
	if (!in_array('woocommerce/woocommerce.php', apply_filters('active_plugins', get_option('active_plugins'))))
	{
		$activated = false;
	}
}

/**
 * Check if WooCommerce is active
 **/
if ($activated)
{
	define('MWB_WRP_DIRPATH', plugin_dir_path( __FILE__ ));
	define('MWB_WRP_URL', plugin_dir_url( __FILE__ ));
	define('MWB_WRP_HOME_URL', home_url());
	
	include_once MWB_WRP_DIRPATH.'/include/woocommerce-recommended-product-class.php';
	include_once MWB_WRP_DIRPATH.'/admin/woocommerce-recommended-product-admin-class.php';
	
	global $wp_version;
	if($wp_version >= '4.9.6'){
		include_once MWB_WRP_DIRPATH.'mwb-wrp-gdpr.php';
	}

	register_activation_hook( __FILE__, 'mwb_wrp_on_activation' );
	
	function mwb_wrp_on_activation()
	{
		global $wpdb;
		$table_name = $wpdb->prefix . 'mwb_wpr_data';
		$charset_collate = $wpdb->get_charset_collate();
		$sql = "CREATE TABLE IF NOT EXISTS $table_name (
					id mediumint(9) NOT NULL AUTO_INCREMENT,
					action varchar(55) DEFAULT '' NOT NULL,
					userid int(10) NOT NULL,
					ipaddress varchar(55) DEFAULT '' NOT NULL,
					productid int(10) NOT NULL,
					type varchar(55) DEFAULT '' NOT NULL,
					date datetime DEFAULT CURRENT_TIMESTAMP,
					status boolean DEFAULT 0,
					count int(10) NOT NULL,
					PRIMARY KEY  (id)
				) $charset_collate;";
		
		require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
		dbDelta( $sql );
	}
	
	/**
	 * This function is used to load language'.
	 * @author makewebbetter<webmaster@makewebbetter.com>
	 * @link http://www.makewebbetter.com/
	 */
	
	function mwb_wrp_load_plugin_textdomain()
	{
		$domain = "woocommerce-recommended-product";
		$locale = apply_filters( 'plugin_locale', get_locale(), $domain );
		load_textdomain( $domain, MWB_WRP_DIRPATH .'languages/'.$domain.'-' . $locale . '.mo' );
		$var=load_plugin_textdomain( $domain, false, plugin_basename( dirname(__FILE__) ) . '/languages' );
	
	}


	/**
	 * This function is used to set url in of setting in plugin row meta
	 * @name mwb_wrp_admin_settings
	 * @param $actions, $plugin_file
	 * @author makewebbetter<webmaster@makewebbetter.com>
	 * @link http://www.makewebbetter.com/
	 */
	function mwb_wrp_admin_settings($actions, $plugin_file) 
	{
		static $plugin;
		if (! isset ( $plugin )) {
	
			$plugin = plugin_basename ( __FILE__ );
		}
		if ($plugin == $plugin_file) {
			$settings = array (
					'settings' => '<a href="' . home_url ( '/wp-admin/admin.php?page=mwb_wrp_recommended_products' ) . '">' . __ ( 'Settings', 'woocommerce-recommended-product' ) . '</a>',
			);
			$actions = array_merge ( $settings, $actions );
		}
		return $actions;
	}
	add_filter ( 'plugin_action_links','mwb_wrp_admin_settings',10,2);
	
	add_action('plugins_loaded', 'mwb_wrp_load_plugin_textdomain');

	add_filter('woocommerce_admin_report_data','mwb_woocommerce_admin_report_data');

	function mwb_woocommerce_admin_report_data($data)
	{
		print_r($data);die;
	}
}
else 
{
	/**
	 * Show warning message if woocommerce is not install
	 *
	 * @name mwb_wrp_plugin_error_notice()
	 * @author makewebbetter<webmaster@makewebbetter.com>
	 * @link http://www.makewebbetter.com/
	 */
	
	function mwb_wrp_plugin_error_notice()
 	{ ?>
 		 <div class="error notice is-dismissible">
 			<p><?php _e( 'Woocommerce is not activated, Please activate Woocommerce first to install WooCommerce Recommended Products.', 'woocommerce-recommended-product' ); ?></p>
   		</div>
   		<style>
   		#message{display:none;}
   		</style>
   	<?php 
 	} 
 	add_action( 'admin_init', 'mwb_wrp_plugin_deactivate' );  
 
 	
 	/**
 	 * Call Admin notices
 	 * 
 	 * @name mwb_wrp_plugin_deactivate()
 	 * @author makewebbetter<webmaster@makewebbetter.com>
 	 * @link http://www.makewebbetter.com/
 	 */
 	
  	function mwb_wrp_plugin_deactivate()
	{
	   deactivate_plugins( plugin_basename( __FILE__ ) );
	   add_action( 'admin_notices', 'mwb_wrp_plugin_error_notice' );
	}		
}	

?>